bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.set_plotter
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.set_plotter